@@ -17,7 +17,25 @@ for your programs and control the amount of informations that be logged to the l
 file. In addition it's possible to define how you wish to open the log file,
 transient or permanent and if you wish you can assign the handler to check the
 inode of the log file. This could be very useful if a rotate mechanism moves
-and zip the log file.
+and zip the log file but you shouldn't forget that inodes aren't available on
+windows.
+
+=head1 CHANGES
+
+Urgent: the log level numbers changed because they wasn't in the right order.
+
+    8 nothing   is still the same
+    7 emergency is now 0
+    6 alert     is now 1
+    5 crit      is now 2
+    4 error     is now 3
+    3 warning   is now 4
+    2 notice    is now 5
+    1 info      is now 6
+    0 debug     is now 7
+
+If you set C<minlevel> and C<maxlevel> as strings in earlier versions than you don't need
+to change your code, but if you used numbers than you have to change it!
 
 =head1 METHODS
 
@@ -26,7 +44,7 @@ and zip the log file.
 Call C<new()> to create a new log handler object.
 
 The C<new()> method expected the options for the log file. The only one mandatory
-option is C<filename>. All other options be set to a default value.
+option is C<filename>. All other options will be set to a default value.
 
 =head2 Log levels
 
@@ -148,7 +166,8 @@ of C<new> failed then you can absorb the error.
 
 Call C<CLOSE()> if you want to close the log file.
 
-NOTE: this option is only useful if you set option C<fileopen> to 1.
+This option is only useful if you set option C<fileopen> to 1. If you don't
+call C<CLOSE()> the log file will be closed automatically before exit().
 
 Note that if you close the log file it's necessary to call C<new()> to reopen it.
 
@@ -156,25 +175,37 @@ Note that if you close the log file it's necessary to call C<new()> to reopen it
 
 =head2 filename
 
-The log file name. This is the only one mandatory option and the script croak if it not set.
+This is the only one mandatory option and the script croak if it not set. You have to
+set a filename, a GLOBREF or you can set a string as an alias for STDOUT and STDERR.
 
-Also you can set a GLOBREF
+Set a file name:
 
-    my $log = Log::Handler->new( filename => \*STDOUT );
+    $log = Log::Handler->new( filename => 'file.log'  );
 
-Or
+Set a file handle
 
-    open $fh, '>>', $logfile or die $!;
-    my $log = Log::Handler->new( filename => $fh );
+    open my $fh, '>', 'file.log' or die $!;
+    $log = Log::Handler->new( filename => $fh );
 
-But note that if you set a GLOBREF to C<filename>, then some options will be forced (overwritten);
+Set a GLOBREF
+
+    open FH, '>', 'file.log' or die $!;
+    $log = Log::Handler->new( filename => \*FH );
+
+Set STDOUT or STDERR
+
+    $log = Log::Handler->new( filename => \*STDOUT );
+    $log = Log::Handler->new( filename => \*STDERR );
+    $log = Log::Handler->new( filename => '*STDOUT' );
+    $log = Log::Handler->new( filename => '*STDERR' );
+
+But note that if you set a GLOBREF to C<filename> some options will be forced (overwritten)
+and you have to control the handles yourself. The forced options are
 
     fileopen => 1
     filelock => 0
     reopen   => 0
 
-You have also to handle the GLOBREF yourself.
-
 =head2 filelock
 
 It's maybe desirable to lock the log file by each write operation. You can set the option
@@ -284,22 +315,22 @@ Take a look to the EXAMPLES to see more.
 With the options C<maxlevel> and C<minlevel> you can set the log levels you
 wish to log to your log file. The log levels are:
 
-    0 - debug
-    1 - info
-    2 - notice, note
-    3 - warning
-    4 - error, err
-    5 - critical, crit
-    6 - alert
-    7 - emergency, emerg
+    7 - debug
+    6 - info
+    5 - notice, note
+    4 - warning
+    3 - error, err
+    2 - critical, crit
+    1 - alert
+    0 - emergency, emerg
 
 The levels C<note>, C<err>, C<crit> and C<emerg> are just shortcuts.
 
 It's possible to set the log level as a string or as number. The default
-C<maxlevel> is 3 and the default C<minlevel> is 7.
+C<maxlevel> is 4 and the default C<minlevel> is 0.
 
-Example: If C<maxlevel> is set to 4 and C<minlevel> to 7 then only emergency (emerg),
-alert, critical (crit) and error (err) messages will be logged to the logfile.
+Example: If C<maxlevel> is set to 4 and C<minlevel> to 0 then only emergency (emerg),
+alert, critical (crit) and error (err) messages will be logged to the log file.
 
 You can set both to 8 if you don't want to log any message.
 
@@ -324,8 +355,8 @@ because on missing params or wrong settings.
        filename => 'file1.log',
        mode     => 'append',
        newline  => 1,
-       maxlevel => 0,
-       minlevel => 7
+       maxlevel => 7,
+       minlevel => 0
     );
 
     $log->debug("this is a debug message");
@@ -363,8 +394,8 @@ Would log this:
     my $log = Log::Handler->new(
        filename   => '/var/run/pid-file1',
        mode       => 'trunc',
-       maxlevel   => 2,
-       minlevel   => 2,
+       maxlevel   => 5,
+       minlevel   => 5,
        prefix     => '',
        timeformat => ''
     );
@@ -386,7 +417,7 @@ Would truncate /var/run/pid-file1 and write just the pid to the logfile.
     my $log = Log::Handler->new(
        filename => "${progname}.log",
        mode     => 'append',
-       maxlevel => 1,
+       maxlevel => 6,
        newline  => 1,
        prefix   => "${hostname}[$pid] [<--LEVEL-->] $progname: "
     );
@@ -407,7 +438,7 @@ Would log:
     my $log = Log::Handler->new(
        filename   => 'file1.log',
        mode       => 'trunc',
-       maxlevel   => 3,
+       maxlevel   => 4,
        prefix     => '',
        timeformat => ''
     );
@@ -495,7 +526,7 @@ SUCH DAMAGES.
 
 package Log::Handler;
 
-our $VERSION = '0.09_02';
+our $VERSION = '0.11_01';
 
 use strict;
 use warnings;
@@ -506,18 +537,18 @@ use POSIX qw(strftime);
 use Params::Validate;
 use Carp qw(croak);
 
-use constant DEBUG     =>  0;
-use constant INFO      =>  1;
-use constant NOTICE    =>  2;
-use constant NOTE      =>  2;
-use constant WARNING   =>  3;
-use constant ERROR     =>  4;
-use constant ERR       =>  4;
-use constant CRITICAL  =>  5;
-use constant CRIT      =>  5;
-use constant ALERT     =>  6;
-use constant EMERGENCY =>  7;
-use constant EMERG     =>  7;
+use constant EMERGENCY =>  0;
+use constant EMERG     =>  0;
+use constant ALERT     =>  1;
+use constant CRITICAL  =>  2;
+use constant CRIT      =>  2;
+use constant ERROR     =>  3;
+use constant ERR       =>  3;
+use constant WARNING   =>  4;
+use constant NOTICE    =>  5;
+use constant NOTE      =>  5;
+use constant INFO      =>  6;
+use constant DEBUG     =>  7;
 use constant NOTHING   =>  8;
 
 # global place holder for error strings
@@ -547,8 +578,8 @@ BEGIN {
          *{"would_log_$routine"} = sub {
             my $self = shift;
             return 1
-               if &{$level} >= $self->{maxlevel}
-               && &{$level} <= $self->{minlevel};
+               if &{$level} >= $self->{minlevel}
+               && &{$level} <= $self->{maxlevel};
             return undef;
          };
       } # end "no strict" block
@@ -559,21 +590,25 @@ sub new {
    my $class = shift;
    my %opts  = ();
    my $self  = bless \%opts, $class;
+   my $bool  = qr/^[10]$/;
 
    %opts = Params::Validate::validate(@_, {
       filename => {
          type => Params::Validate::SCALAR | Params::Validate::GLOBREF,
       },
       filelock => {
-         type => Params::Validate::BOOLEAN,
+         type => Params::Validate::SCALAR,
+         regex => $bool,
          default => 1,
       },
       fileopen => {
-         type => Params::Validate::BOOLEAN,
+         type => Params::Validate::SCALAR,
+         regex => $bool,
          default => 1,
       },
       reopen => {
-         type  => Params::Validate::BOOLEAN,
+         type  => Params::Validate::SCALAR,
+         regex => $bool,
          default => 1,
       },
       mode => {
@@ -582,12 +617,13 @@ sub new {
          default => 'excl',
       },
       autoflush => {
-         type => Params::Validate::BOOLEAN,
+         type => Params::Validate::SCALAR,
+         regex => $bool,
          default => 1,
       },
       permissions => {
          type => Params::Validate::SCALAR,
-         regex => qr/^[0-7]{3}([0-7]*)$/,
+         regex => qr/^[0-7]{3,4}$/,
          default => '0640',
       },
       timeformat => {
@@ -595,25 +631,27 @@ sub new {
          default => '%b %d %H:%M:%S',
       },
       newline => {
-         type => Params::Validate::BOOLEAN,
+         type => Params::Validate::SCALAR,
+         regex => $bool,
          default => 0,
       },
       prefix => {
          type => Params::Validate::SCALAR,
          default => '[<--LEVEL-->] ',
       },
-      maxlevel => {
-         type => Params::Validate::SCALAR,
-         regex => qr/^([0-8]|debug|info|notice|note|warning|error|err|critical|crit|alert|emergency|emerg)$/,
-         default => 3,
-      },
       minlevel => {
          type => Params::Validate::SCALAR,
          regex => qr/^([0-8]|debug|info|notice|note|warning|error|err|critical|crit|alert|emergency|emerg)$/,
-         default => 7,
+         default => 0,
+      },
+      maxlevel => {
+         type => Params::Validate::SCALAR,
+         regex => qr/^([0-8]|debug|info|notice|note|warning|error|err|critical|crit|alert|emergency|emerg)$/,
+         default => 4,
       },
       die_on_errors => {
-         type => Params::Validate::BOOLEAN,
+         type => Params::Validate::SCALAR,
+         regex => $bool,
          default => 1,
       },
    });
@@ -627,8 +665,15 @@ sub new {
    } # end "no strict" block
 
    # if option filename is a GLOB, then we force some options
-   if (ref($opts{filename}) eq 'GLOB') {
-      $opts{fh}       = $opts{filename};
+   if (ref($opts{filename}) eq 'GLOB' || $opts{filename} =~ /^\*/) {
+      $opts{fh} = $opts{filename};
+   } elsif ($opts{filename} eq '*STDOUT') {
+      $opts{fh} = \*STDOUT;
+   } elsif ($opts{filename} eq '*STDERR') {
+      $opts{fh} = \*STDERR;
+   }
+
+   if (defined $opts{fh}) {
       $opts{fileopen} = 1;
       $opts{reopen}   = 0;
       $opts{filelock} = 0;
@@ -669,6 +714,13 @@ sub CLOSE {
 
 sub errstr { return $__PACKAGE__::errstr }
 
+sub DESTROY {
+   my $self = shift;
+   return unless $self->{fh};
+   flock($self->{fh}, LOCK_UN);
+   close($self->{fh});
+}
+
 #
 # private stuff
 #
@@ -761,8 +813,8 @@ sub _print {
    {  # return if we don't want log this level
       no strict 'refs';
       return 1
-         unless &{$level} >= $self->{maxlevel}
-             && &{$level} <= $self->{minlevel};
+         unless &{$level} >= $self->{minlevel}
+             && &{$level} <= $self->{maxlevel};
    }
 
    if ($self->{fileopen} == 0) {
